from django.db import models
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse_lazy

class Customer(models.Model):
    name = models.CharField(max_length=255, default='')
    address = models.CharField(max_length=255, default='')
    logo = models.URLField()
    companyRegister = models.CharField(default='', max_length=255)
    contactFirstName = models.CharField(default='', max_length=255)
    contactLastName = models.CharField(default='', max_length=255)
    contactMail = models.EmailField(default='')
    contactPhone = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        permissions = (
            ('view_client', 'Read'),
            ('control_client', 'Control'),
        )

    def __str__(self):
        return self.name


class Project(models.Model):
    name = models.CharField(max_length=255, default='')
    description = models.CharField(max_length=255, default='')
    number = models.PositiveIntegerField(default='0', blank=True)
    customer = models.ForeignKey(Customer, on_delete=models.DO_NOTHING)  # WARN add import
    team = models.ManyToManyField(User, through='Job', blank=True)
    businessProvider = models.CharField(max_length=255, blank=True, null=True)
    businessProviderFee = models.PositiveIntegerField(default='0', blank=True)
    jabberID = models.CharField(max_length=255, blank=True, null=True)
    jabberRoom = models.BooleanField(default=True)

    def get_absolute_url(self):
        return reverse_lazy('project-detail', kwargs={'pk': self.pk})

    class Meta:
        permissions = (
            ('view_project', 'Read'),
            ('control_project', 'Control'),
        )
        rdf_type = 'doap:project'

    def __str__(self):
        return self.name

class Job(models.Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE)
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name



from django.contrib import admin
from guardian.admin import GuardedModelAdmin
from .models import Project, Job, Customer

admin.site.register(Project, GuardedModelAdmin)
admin.site.register(Job)
admin.site.register(Customer)



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 17:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0004_remove_project_chatconfig'),
        ('djangoldp_project', '0004_auto_20190121_1544'),
    ]

    operations = [
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-12-20 09:39
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion

def migrate_data(apps, schema_editor):
    Project = apps.get_model('djangoldp_project', 'Project')
    ChatConfig = apps.get_model('djangoldp_account', 'ChatConfig')
    for project in Project.objects.all():
        chat_config = ChatConfig()
        chat_config.jabberID = project.jabberID
        chat_config.jabberRoom = project.jabberRoom
        chat_config.save()
        project.chatConfig = chat_config
        project.save()


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_account', '0001_initial'),
        ('djangoldp_project', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='chatConfig',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='projects', to='djangoldp_account.ChatConfig'),
        ),
        migrations.RunPython(migrate_data),
        migrations.RemoveField(
            model_name='project',
            name='jabberID',
        ),
        migrations.RemoveField(
            model_name='project',
            name='jabberRoom',
        ),

    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-11-24 14:05
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Customer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('address', models.CharField(default='', max_length=255)),
                ('logo', models.URLField()),
            ],
            options={
                'permissions': (('view_client', 'Read'), ('control_client', 'Control')),
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('description', models.CharField(default='', max_length=255)),
                ('number', models.PositiveIntegerField(blank=True, default='0')),
                ('jabberID', models.CharField(blank=True, max_length=255, null=True)),
                ('jabberRoom', models.NullBooleanField()),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='Customer')),
                ('team', models.ManyToManyField(blank=True, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (('view_project', 'Read'), ('control_project', 'Control')),
            },
        ),

    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 17:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20190121_1701'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='chatConfig',
        ),
    ]
